package Genealogy::ObituaryDailyTimes::DB::obituaries;

=head1 NAME

Genealogy::ObituaryDailyTimes::DB::obituaries

=cut

use strict;
use warnings;

use Genealogy::ObituaryDailyTimes::DB;

our @ISA = ('Genealogy::ObituaryDailyTimes::DB');

1;
